@@ -159,10 +159,10 @@ class dyagram:
 
                     executor.submit(self.__discover_lldp_neighbors, device)
                     self.log.info(f"DEVICE: {device} - Submitted for discover_lldp_neighbors")
-                    executor.submit(self.discover_routes, device)
-                    self.log.info(f"DEVICE: {device} - Submitted for discover_routes")
-                    # executor.submit(self.discover_dynamic_routing_neighbors, device)
-                    # self.log.info(f"DEVICE: {device} - Submitted for discover_dynamic_routing_neighbors")
+                    # executor.submit(self.discover_routes, device)
+                    # self.log.info(f"DEVICE: {device} - Submitted for discover_routes")
+                    executor.submit(self.discover_dynamic_routing_neighbors, device)
+                    self.log.info(f"DEVICE: {device} - Submitted for discover_dynamic_routing_neighbors")
 
                     self._devices_queried.append(device)
 
